@@ -102,9 +102,14 @@ def read_table(file_path: str):
 ####################     
 def add_af(line, af_accessor:VcfAccessor, population:str = 'nfe', rsid_column_name:str = 'rsid'):
     try:
-        line['af'] = af_accessor.get_af_by_pop(line['ID'], 'AF_' + population)[line['ALT']]
+        af = af_accessor.get_af_by_pop(line['ID'], 'AF_' + population)
+        line['af'] = af[line['ALT']]
     except DataNotPresentError:
         line['af'] = 0
+    except Exception:
+        ### TODO convert alternate alleles
+        af = af_accessor.get_af_by_pop(line['ID'], 'AF_' + population)
+        line['af'] = af[list(af.keys())[1]]
     return line
 
 ####################
